==> vue-cli-plugin-demo-test2-1.0.0.tgz: package/generator/index.js <==
import ApplyTemplate from './templates/src/components/ComboInput.vue';
import ComboInput from './templates/src/components/ComboInput.vue';
import CreateBtn from './templates/src/components/ CreateBtn.vue';
import CustomDialog from './templates/src/components/CustomDialog.vue';
import DetailsBtn from './templates/src/components/DetailsBtn.vue';
import FileSelector from './templates/src/components/FileSelector.vue';
import NavMenu from './templates/src/components/NavMenu.vue';
import TemplateDetail from './templates/src/components/TemplateDetail.vue';

const components = [
    ApplyTemplate,
    ComboInput,
    CreateBtn,
    CustomDialog,
    DetailsBtn,
    FileSelector,
    NavMenu,
    TemplateDetail
];

const install = function(Vue, opts = {}) {
    locale.use(opts.locale);
    locale.i18n(opts.i18n);

    components.forEach(component => {
        Vue.component(component.name, component);
    });

    Vue.use(InfiniteScroll);
    Vue.use(Loading.directive);

    Vue.prototype.$ELEMENT = {
        size: opts.size || '',
        zIndex: opts.zIndex || 2000
    };

    Vue.prototype.$loading = Loading.service;
    Vue.prototype.$msgbox = MessageBox;
    Vue.prototype.$alert = MessageBox.alert;
    Vue.prototype.$confirm = MessageBox.confirm;
    Vue.prototype.$prompt = MessageBox.prompt;
    Vue.prototype.$notify = Notification;
    Vue.prototype.$message = Message;

};

/* istanbul ignore if */
if (typeof window !== 'undefined' && window.Vue) {
    install(window.Vue);
}

export default {
    version: '2.15.3',
    locale: locale.use,
    i18n: locale.i18n,
    install,
    CollapseTransition,
    Loading,

    ApplyTemplate,
    ComboInput,
    CreateBtn,
    CustomDialog,
    DetailsBtn,
    FileSelector,
    NavMenu,
    TemplateDetail
};

==> vue-cli-plugin-demo-test2-1.0.2.tgz: package/generator/index.js <==
import ApplyTemplate from './templates/src/components/ComboInput.vue';
import ComboInput from './templates/src/components/ComboInput.vue';
import CreateBtn from './templates/src/components/ CreateBtn.vue';
import CustomDialog from './templates/src/components/CustomDialog.vue';
import DetailsBtn from './templates/src/components/DetailsBtn.vue';
import FileSelector from './templates/src/components/FileSelector.vue';
import NavMenu from './templates/src/components/NavMenu.vue';
import TemplateDetail from './templates/src/components/TemplateDetail.vue';

const components = [
    ApplyTemplate,
    ComboInput,
    CreateBtn,
    CustomDialog,
    DetailsBtn,
    FileSelector,
    NavMenu,
    TemplateDetail
];

const install = function(Vue, opts = {}) {
    // locale.use(opts.locale);
    // locale.i18n(opts.i18n);

    components.forEach(component => {
        Vue.component(component.name, component);
    });

    // Vue.use(InfiniteScroll);
    // Vue.use(Loading.directive);

    // Vue.prototype.$ELEMENT = {
    //     size: opts.size || '',
    //     zIndex: opts.zIndex || 2000
    // };

    // Vue.prototype.$loading = Loading.service;
    // Vue.prototype.$msgbox = MessageBox;
    // Vue.prototype.$alert = MessageBox.alert;
    // Vue.prototype.$confirm = MessageBox.confirm;
    // Vue.prototype.$prompt = MessageBox.prompt;
    // Vue.prototype.$notify = Notification;
    // Vue.prototype.$message = Message;

};

/* istanbul ignore if */
if (typeof window !== 'undefined' && window.Vue) {
    install(window.Vue);
}

export default {
    version: '1.0.2',
    // locale: locale.use,
    // i18n: locale.i18n,
    install,
    // CollapseTransition,

    ApplyTemplate,
    ComboInput,
    CreateBtn,
    CustomDialog,
    DetailsBtn,
    FileSelector,
    NavMenu,
    TemplateDetail
};
